scinumtools.phys package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   scinumtools.phys.units

Submodules
----------

scinumtools.phys.ConstantsClass module
--------------------------------------

.. automodule:: scinumtools.phys.ConstantsClass
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: scinumtools.phys
   :members:
   :undoc-members:
   :show-inheritance:
